#include "scene.h"
#include <fstream>

void Scene::Load(char *fileName) {

  ifstream ifs(fileName);
  if (ifs.fail()) {
    cerr << "ERROR: could not open file: " << fileName << endl;
  }
  while (1) {
    char keyword[100];
    ifs >> keyword;
    if (ifs.fail())
      break;
    if (!strcmp(keyword, "endOfScene")) {
      break;
    }
    else if (!strcmp(keyword, "circle")) {
      if (circlesN == SCENE_MAX_CIRCLESN) {
        cerr << "ERROR: too many circles" << endl;
        return;
      }
      else {
        circles[circlesN] = new Circle(ifs);
        circlesN++;
      }
    }
    else if (!strcmp(keyword, "frameBuffer")) {
      LoadFrameBuffer(ifs);
    }
    else {
      cerr << "ERROR: unknown keyword: " << keyword << endl;
      break;
    }
  }
  ifs.close();

}

void Scene::Render() {

  for (int circlei = 0; circlei < circlesN; circlei++) {
    circles[circlei]->Rasterize(*frameBuffer);
  }

#if 0
  V2D eps[2];
  eps[0] = V2D(10.13f, 10.9f);
  eps[1] = V2D(40.1f, 12.2f);
  Segment s2d(eps);
  s2d.Rasterize(*frameBuffer);
#endif

  frameBuffer->Show();

}

void Scene::LoadFrameBuffer(istream &istr) {

  bool readResolution = false;
  int w, h;
  while (1) {
    char keyword[100];
    istr >> keyword;
    if (istr.fail()) {
      cerr << "ERROR: while reading frame buffer" << endl;
      return;
    }
    if (!strcmp(keyword, "endOfFrameBuffer")) {
      break;
    }
    else if (!strcmp(keyword, "resolution")) {
      istr >> w >> h;
      readResolution = true;
    }
    else if (!strcmp(keyword, "backgroundColor")) {
      istr >> backgroundColor;
    }
  }
  if (!readResolution) {
    cerr << "ERROR: did not read all required frame buffer data" << endl;
  }

  frameBuffer = new Image(w, h);
  frameBuffer->Clear(backgroundColor);

}

