#include "segment.h"
#include <math.h>

Segment::Segment(V2D *_eps) {

  eps[0] = _eps[0];
  eps[1] = _eps[1];
  color = Color((char)219);

}

void Segment::Rasterize(Image &image) {

  // 1. Find out how many one-pixel steps one needs to take
  //      as the longest of the x and y dimensions
  V2D segVector = eps[1]-eps[0];
  float adx = fabsf(segVector[0]);
  float ady = fabsf(segVector[1]);
  int stepsN;
  if (adx > ady) {
    stepsN = (int) ceilf(adx);
  }
  else {
    stepsN = (int) ceilf(ady);
  }

  // 2. Set the increments dx and dy (one of them is 1 pixel)
  V2D dxdy = segVector/(float)stepsN;

  // 3. Loop to rasterize the segment
  //      - clip one pixel at the time
  for (int i = 0; i < stepsN+1; i++) {
    V2D currPoint = eps[0] + dxdy*(float)i;
    currPoint.SetItsPixel(image, color);
  }

}